@@ -17,7 +17,7 @@ def app() -> None:
     print("")
     try:
         config: dict = dict()
-        config_source: str= os.getenv('CHAOTIC_CONFIG', 'config.yaml')
+        config_source: str = os.getenv('CHAOTIC_CONFIG', 'config.yaml')
 
         if config_source.startswith("http"):
             res: Response = requests.get(
@@ -66,13 +66,18 @@ def run_periodic(interval: int = 1) -> None:
         time.sleep(1)
 
 def main() -> None:
-    log.info(f"Starting version {__version__}")
-
     parser: ArgumentParser = ArgumentParser()
-    parser.add_argument("--periodic", help="Run periodic", action="store_true")
-    parser.add_argument("--interval", help="Interval in minutes", type=int, default=1)
+    parser.add_argument("--periodic", help="run periodic", action="store_true")
+    parser.add_argument("--interval", help="set interval in minutes", type=int, default=1)
+    parser.add_argument("--version", help="show version", action="store_true")
     args = parser.parse_args()
 
+    if args.version:
+        print(f"version {__version__}")
+        sys.exit(0)
+
+    log.info(f"Starting version {__version__}")
+
     if args.periodic:
         try:
             run_periodic(args.interval)
